# terratalk

[![Build Status](https://travis-ci.org/lifeofguenter/terratalk.svg?branch=master)](https://travis-ci.org/lifeofguenter/terratalk)
[![PyPI](https://img.shields.io/pypi/v/terratalk.svg)](https://pypi.org/project/terratalk/)
[![License](https://img.shields.io/github/license/lifeofguenter/terratalk.svg)](LICENSE)
